about summary refs log tree commit diff
path: root/sysdeps/powerpc/fpu/e_sqrt.c
diff options
context:
space:
mode:
authorPhilippe De Muyter <phdm@macqel.be>2009-11-06 09:33:27 -0800
committerUlrich Drepper <drepper@redhat.com>2009-11-06 09:33:27 -0800
commit868f7a4053502783ab0348736230f093a78f3d46 (patch)
tree1de9f014157d3ce070b21046a57eadabfa03b6bf /sysdeps/powerpc/fpu/e_sqrt.c
parent685cb08356bb9408c50970711ba3f4726e95b638 (diff)
downloadglibc-868f7a4053502783ab0348736230f093a78f3d46.tar.gz
glibc-868f7a4053502783ab0348736230f093a78f3d46.tar.xz
glibc-868f7a4053502783ab0348736230f093a78f3d46.zip
Fix spelling of (Newton-)Raphson
Diffstat (limited to 'sysdeps/powerpc/fpu/e_sqrt.c')
-rw-r--r--sysdeps/powerpc/fpu/e_sqrt.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sysdeps/powerpc/fpu/e_sqrt.c b/sysdeps/powerpc/fpu/e_sqrt.c
index 24e0dd3523..e95b786a00 100644
--- a/sysdeps/powerpc/fpu/e_sqrt.c
+++ b/sysdeps/powerpc/fpu/e_sqrt.c
@@ -35,7 +35,7 @@ extern const float __t_sqrt[1024];
 /* The method is based on a description in
    Computation of elementary functions on the IBM RISC System/6000 processor,
    P. W. Markstein, IBM J. Res. Develop, 34(1) 1990.
-   Basically, it consists of two interleaved Newton-Rhapson approximations,
+   Basically, it consists of two interleaved Newton-Raphson approximations,
    one to find the actual square root, and one to find its reciprocal
    without the expense of a division operation.   The tricky bit here
    is the use of the POWER/PowerPC multiply-add operation to get the
@@ -44,7 +44,7 @@ extern const float __t_sqrt[1024];
    The argument reduction works by a combination of table lookup to
    obtain the initial guesses, and some careful modification of the
    generated guesses (which mostly runs on the integer unit, while the
-   Newton-Rhapson is running on the FPU).  */
+   Newton-Raphson is running on the FPU).  */
 
 #ifdef __STDC__
 double
@@ -102,7 +102,7 @@ __slow_ieee754_sqrt (x)
 	  /* complete the INSERT_WORDS (sx, sxi, xi1) operation.  */
 	  sx = iw_u.value;
 
 	  /* Here we have three Newton-Rhapson iterations each of a
 	     division and a square root and the remainder of the
 	     argument reduction, all interleaved.   */
 	  sd = -(sg * sg - sx);
@@ -102,7 +102,7 @@ __slow_ieee754_sqrt (x)
 	  sx = iw_u.value;
 
-	  /* Here we have three Newton-Rhapson iterations each of a
+	  /* Here we have three Newton-Raphson iterations each of a
 	     division and a square root and the remainder of the
 	     argument reduction, all interleaved.   */